@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
+from __future__ import absolute_import
+
 import datetime
 import re
 import urlparse
 
-from .utils import to_unicode
+from ..serializers import to_unicode
 
 
 __all__ = ['Required', 'IsNumber', 'IsNaturalNumber', 'IsDate',
